{% extends 'ddm/admin/generic/page_with_form.html' %}

{% block page_title %}Delete File Uploader{% endblock %}

{% block main_heading %}Delete File Uploader "{{ object.name }}"{% endblock %}

{% block main_top %}
<p>You are about to delete the following File Uploader:</p>

<div class="ddm-admin-form">
  <p>
    <label>Name:</label>
    {{ object.name }}
  </p>
</div>

<div class="mt-4">
  <p>The donation instructions associated with this File Uploader will also be deleted. The associated donation blueprints will not be deleted.</p>
  <div class="ddm-admin-form">
    <p>The following instructions are associated with this File Uploader:</p>
    <div>
      <p><b>Instructions:</b></p>
      <ul>
        {% for instruction in object.instruction_set.all %}
        <li>{{ instruction }}</li>
        {% empty %}
        No instructions associated to this blueprint were found.
        {% endfor %}
      </ul>
    </div>
  </div>
</div>

<form method='post'>
  {% csrf_token %}
  <p><b>Are you sure you want to delete this File Uploader along with all associated instructions? This action cannot be reversed.</b></p>
  <input class="ddm-btn ddm-btn-red" type="submit" value="Delete File Uploader">
  <p class="mt-3">
    <a href="{% url 'data-donation-overview' project.pk %}">&#129040; Cancel</a>
  </p>
</form>
{% endblock %}

{% block main_form %}{% endblock %}


{% block breadcrumbs %}
<a href="{% url 'project-list' %}">Projects</a> /
<a href="{% url 'project-detail' project.pk %}">"{{ project.name|truncatechars:15 }}" Project</a> /
<a href="{% url 'data-donation-overview' project.pk %}">Data Donation</a> /
Delete File Uploader
{% endblock %}
