# Generated by Django 3.2.13 on 2023-01-30 16:33

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0031_auto_20230122_1828'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='questionbase',
            options={'ordering': ['index']},
        ),
        migrations.AlterModelManagers(
            name='matrixquestion',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='multichoicequestion',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='openquestion',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='questionbase',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='semanticdifferential',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='singlechoicequestion',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='transition',
            managers=[
            ],
        ),
        migrations.AlterField(
            model_name='questionbase',
            name='blueprint',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='ddm.donationblueprint'),
        ),
        migrations.AlterField(
            model_name='questionbase',
            name='index',
            field=models.PositiveIntegerField(default=1, verbose_name='Page'),
        ),
    ]
