/* FONTS */
@font-face {
    font-family: 'Nunito Sans';
    src: url('../fonts/NunitoSans/NunitoSans-Regular.ttf');
    font-style: normal;
    font-weight: 400;
}

@font-face {
    font-family: 'Nunito Sans';
    src: url('../fonts/NunitoSans/NunitoSans-Italic.ttf');
    font-style: italic;
    font-weight: 400;
}

@font-face {
    font-family: 'Nunito Sans';
    src: url('../fonts/NunitoSans/NunitoSans-Bold.ttf');
    font-style: normal;
    font-weight: 700;
}

@font-face {
    font-family: 'Nunito Sans';
    src: url('../fonts/NunitoSans/NunitoSans-BoldItalic.ttf');
    font-style: italic;
    font-weight: 700;
}

@font-face {
    font-family: 'Nunito Sans';
    src: url('../fonts/NunitoSans/NunitoSans-Light.ttf');
    font-style: normal;
    font-weight: 300;
}

@font-face {
    font-family: 'Nunito Sans';
    src: url('../fonts/NunitoSans/NunitoSans-LightItalic.ttf');
    font-style: italic;
    font-weight: 300;
}

.research-interface {
    font-family: 'Nunito Sans', sans-serif;
}

.research-interface a,
.a-no-link {
    color: #007b74;
    text-decoration: none;
    cursor: pointer;
}
.research-interface a:hover {
    color: #005955;
}

.ddm-btn {
    background-color: #1a1a1a;
    color: white !important;
    border-radius: 5px;
    border: 0px;
    padding: 3px 10px !important;
    font-size: 0.9rem;
    text-decoration: none;
}
.ddm-btn:hover {
    filter: brightness(85%);
    color: white;
}

.ddm-btn-red {
    background-color: #840600;
    border: 0px;
    width: 160px;
}