{% extends 'ddm/admin/base.html' %}

{% block page_title %}Permission Denied{% endblock %}

{% block main_heading %}Permission Denied{% endblock %}

{% block main_body %}
<div>
  You do not fulfill the criteria to create a DDM research profile.
  For further information, please contact your administrator.
</div>
{% endblock %}
