# Generated by Django 3.2.13 on 2023-01-04 12:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0022_auto_20230103_1433'),
    ]

    operations = [
        migrations.RenameField(
            model_name='donationproject',
            old_name='intro_text',
            new_name='briefing_text',
        ),
        migrations.RenameField(
            model_name='donationproject',
            old_name='outro_text',
            new_name='debriefing_text',
        ),
        migrations.RemoveField(
            model_name='donationproject',
            name='collaborators',
        ),
        migrations.AddField(
            model_name='donationproject',
            name='briefing_consent_enabled',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='donationproject',
            name='briefing_consent_label_no',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name='donationproject',
            name='briefing_consent_label_yes',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='donationproject',
            name='expected_url_parameters',
            field=models.CharField(blank=True, default='', help_text='Separate multiple parameters with a semikolon (";"). Semikolons are not allowed as part of the expected url parameters.', max_length=500, verbose_name='Expected URL parameter'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='donationproject',
            name='redirect_target',
            field=models.CharField(blank=True, default='', help_text='Always include <i>http://</i> or <i>https://</i> in the redirect target. If URL parameter extraction is enabled for this project, you can include the extracted URL parameters in the redirect target as follows: "https://redirect.me/?redirectpara=<b>{{URLParameter}}</b>".', max_length=2000, verbose_name='Redirect target'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='fileuploader',
            name='upload_type',
            field=models.CharField(choices=[('zip file', 'Zip File'), ('single file', 'Single File')], default='single file', max_length=20, verbose_name='Upload type'),
        ),
    ]
