{% extends 'ddm/admin/generic/page_with_form.html' %}

{% block page_title %}Create {{ question_type }}{% endblock %}

{% block main_heading %}Create New {{ question_type }}{% endblock %}

{% block submit_label %}Create Question{% endblock %}

{% block cancel_target %}{% url 'questionnaire-overview' project_pk %}{% endblock %}

{% block breadcrumbs %}
<a href="{% url 'project-list' %}">Projects</a> /
<a href="{% url 'project-detail' project_pk %}">"{{ project.name|truncatechars:15 }}" Project</a> /
<a href="{% url 'questionnaire-overview' project_pk %}">Questionnaire</a> /
Create Question
{% endblock %}
