{% extends 'ddm/admin/generic/page_with_form.html' %}

{% block page_title %}Delete Instruction Page{% endblock %}

{% block main_heading %}Delete Instruction Page{% endblock %}

{% block main_top %}
<p>You are about to delete the following instruction page:</p>
<div>
  <table class="table">
    <tr>
      <td style="width: 16%">Related File Uploader:</td>
      <td>{{ file_uploader }}</td>
    </tr>
    <tr>
      <td>Index:</td>
      <td>{{ object.index }}</td>
    </tr>
    <tr>
      <td>Text:</td>
      <td>{{ object.text | safe }}</td>
    </tr>
  </table>
</div>
{% endblock %}


{% block main_form%}
<form method='post'>
  {% csrf_token %}
  <p>Are you sure you want to delete this instruction page? <b>This action cannot be reversed.</b></p>
  <input class="ddm-btn ddm-btn-red" type="submit" value="Delete Instruction Page">
  <p class="mt-3">
    <a href="{% url 'instruction-overview' project_pk file_uploader.pk %}">&#129040; Cancel</a>
  </p>
</form>
{% endblock %}


{% block breadcrumbs %}
<a href="{% url 'project-list' %}">Projects</a> /
<a href="{% url 'project-detail' project_pk %}">"{{ project.name|truncatechars:15 }}" Project</a> /
<a href="{% url 'data-donation-overview' project_pk %}">Data Donation</a> /
<a href="{% url 'file-uploader-edit' project_pk file_uploader.pk %}">File Uploader "{{ file_uploader.name|truncatechars:15 }}"</a> /
<a href="{% url 'instruction-overview' project_pk file_uploader.pk %}">Instructions</a> /
Delete Instruction Page
{% endblock %}
