# Generated by Django 3.2.13 on 2022-12-22 08:25

import ckeditor.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0020_auto_20221216_1428'),
    ]

    operations = [
        migrations.AddField(
            model_name='blueprintcontainer',
            name='index',
            field=models.PositiveIntegerField(default=1, null=True),
        ),
        migrations.AddField(
            model_name='donationblueprint',
            name='index',
            field=models.PositiveIntegerField(default=1, null=True),
        ),
        migrations.AlterField(
            model_name='donationproject',
            name='contact_information',
            field=ckeditor.fields.RichTextField(help_text='Please provide the contact information of the person responsible for the conduction of this study. The contact information will be accessible for participants during the data donation.', null=True, verbose_name='Contact information'),
        ),
        migrations.AlterField(
            model_name='donationproject',
            name='data_protection_statement',
            field=ckeditor.fields.RichTextField(help_text='Please provide a data protection statement for your data donation collection. This should include the purpose for which the data is collected, how it will be stored, and who will have access to the data.', null=True, verbose_name='Data Protection Statement'),
        ),
        migrations.AlterField(
            model_name='questionbase',
            name='variable_name',
            field=models.SlugField(help_text='Will be used in the data export to identify responses to this question.', verbose_name='Variable name for storing response'),
        ),
    ]
