.carousel[data-v-39892445]{min-height:250px}.carousel-control-next[data-v-39892445],.carousel-control-prev[data-v-39892445]{width:auto}.carousel-inner[data-v-39892445]{padding-left:42px;padding-right:42px}.carousel-item[data-v-39892445]{transition:transform .3s ease,opacity .3s ease-out}.accordion-button[data-v-84a40a76]:focus{outline:none;box-shadow:none}.accordion-button[data-v-84a40a76]:not(.collapsed){background-color:#fff;color:#000;border-bottom:none;box-shadow:none}.accordion-button[data-v-84a40a76]{background-color:#efefef;color:#000;border-bottom:none}.accordion-button[data-v-84a40a76]:not(.collapsed):after{background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23212529'%3E%3Cpath fill-rule='evenodd' d='M1.646 4.646a.5.5 0 0 1 .708 0L8 10.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708z'/%3E%3C/svg%3E")}.accordion-button[data-v-84a40a76],.accordion-item[data-v-84a40a76],.accordion-item[data-v-84a40a76]:first-of-type{border-radius:0!important}.form-check-label[data-v-84a40a76]{cursor:pointer}.ul-success[data-v-84a40a76]{background-color:#55ff5517}.ul-failed[data-v-84a40a76]{background-color:#f8d7da}.ul-status-icon[data-v-84a40a76]{font-size:2.5rem}.ul-status p[data-v-84a40a76],.ul-status-description p[data-v-84a40a76],.ul-status-message p[data-v-84a40a76],.ul-status-message ul[data-v-84a40a76]{margin:0}.text-grey[data-v-84a40a76]{color:#d0d0d0}.bp-description[data-v-84a40a76]{font-weight:700}.ul-data-container[data-v-84a40a76]{display:block;padding-left:10px;padding-right:10px;border-radius:5px}.ul-data-condensed[data-v-84a40a76]{max-height:150px;overflow:hidden}.ul-data-expanded[data-v-84a40a76]{max-height:500px;overflow-y:scroll}.ul-data-container th[data-v-84a40a76]{position:sticky;top:0;z-index:1;background-color:#fff!important;box-shadow:0 1px #000}.ul-data-expansion-control[data-v-84a40a76]{text-align:center;z-index:10;position:relative;cursor:pointer;border-radius:5px}.control-expanded[data-v-84a40a76]{background:#fff;margin-top:0;height:30px}.control-condensed[data-v-84a40a76]{background:#fff;background:linear-gradient(180deg,hsla(0,0%,100%,0),#fff 50%);height:75px;margin-top:-75px;padding-top:45px}.fs-09[data-v-84a40a76]{font-size:.9rem}.w-small[data-v-84a40a76]{max-width:33px}.consent-question-container[data-v-84a40a76]{padding:20px 10px;width:100%}#uapp{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;color:#2c3e50}.default-modal{background:#fff;z-index:2000;position:absolute;top:35%;margin-left:auto;margin-right:auto;left:0;right:0;width:30%;border-radius:5px}.modal-backdrop{position:fixed;height:100%;width:100%;background:#959595;opacity:.75;z-index:1000}.custom-modal-container{width:100%;max-width:none;-webkit-animation:fade-in-right .6s ease forwards;animation:fade-in-right .6s ease forwards}.custom-modal-content{background:#212529!important;color:#fff!important;border:none;border-radius:0;font-size:2.5rem!important;display:flex;justify-content:center;align-items:center;position:relative;overflow:hidden;padding-bottom:30px;box-shadow:0 3px #ffffff17}@-webkit-keyframes fade-in-right{0%{opacity:0;transform:translateX(-15px)}to{opacity:1;transform:translateX(0)}}@keyframes fade-in-right{0%{opacity:0;transform:translateX(-15px)}to{opacity:1;transform:translateX(0)}}.dot-floating{position:relative;width:12px;height:12px;border-radius:6px;background-color:#009c94;color:#009c94;-webkit-animation:dotFloating 3s cubic-bezier(.15,.6,.9,.1) infinite;animation:dotFloating 3s cubic-bezier(.15,.6,.9,.1) infinite}.dot-floating:after,.dot-floating:before{content:"";display:inline-block;position:absolute;top:0}.dot-floating:before{left:-14px;-webkit-animation:dotFloatingBefore 3s ease-in-out infinite;animation:dotFloatingBefore 3s ease-in-out infinite}.dot-floating:after,.dot-floating:before{width:12px;height:12px;border-radius:6px;background-color:#009c94;color:#009c94}.dot-floating:after{left:-26px;-webkit-animation:dotFloatingAfter 3s cubic-bezier(.4,0,1,1) infinite;animation:dotFloatingAfter 3s cubic-bezier(.4,0,1,1) infinite}.ddm-btn{background-color:#1a1a1a;color:#fff!important;border-radius:5px;border:1px solid #8e8e8e;padding:3px 10px!important;font-size:.9rem;text-decoration:none}.color-blue{color:#0068b3}@-webkit-keyframes dotFloating{0%{left:calc(-50% - 5px)}75%{left:calc(50% + 105px)}to{left:calc(50% + 105px)}}@keyframes dotFloating{0%{left:calc(-50% - 5px)}75%{left:calc(50% + 105px)}to{left:calc(50% + 105px)}}@-webkit-keyframes dotFloatingBefore{0%{left:-50px}50%{left:-14px}75%{left:-50px}to{left:-50px}}@keyframes dotFloatingBefore{0%{left:-50px}50%{left:-14px}75%{left:-50px}to{left:-50px}}@-webkit-keyframes dotFloatingAfter{0%{left:-100px}50%{left:-26px}75%{left:-100px}to{left:-100px}}@keyframes dotFloatingAfter{0%{left:-100px}50%{left:-26px}75%{left:-100px}to{left:-100px}}