# Generated by Django 3.2.13 on 2023-01-05 15:02

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0024_customtoken'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='CustomToken',
            new_name='ProjectAccessToken',
        ),
    ]
