# Generated by Django 3.2.13 on 2022-06-29 14:51

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ddm', '0009_auto_20220629_1641'),
    ]

    operations = [
        migrations.AlterField(
            model_name='donationblueprint',
            name='expected_fields',
            field=models.TextField(validators=[django.core.validators.RegexValidator('^((["][^"]+["]))(\\s*,\\s*((["][^"]+["])))*[,\\s]*$', message='Field must contain one or multiple comma separated strings. Strings must be enclosed in double quotes ("string").')]),
        ),
        migrations.AlterField(
            model_name='donationblueprint',
            name='extracted_fields',
            field=models.TextField(blank=True, null=True, validators=[django.core.validators.RegexValidator('^((["][^"]+["]))(\\s*,\\s*((["][^"]+["])))*[,\\s]*$', message='Field must contain one or multiple comma separated strings. Strings must be enclosed in double quotes ("string").')]),
        ),
    ]
